@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_Tools_src_global_qttools_config_p_h_H
+#define QT_FEATURES_Tools_src_global_qttools_config_p_h_H
+
 #define QT_FEATURE_assistant 1
 
 #define QT_FEATURE_clang 1
@@ -26,3 +29,5 @@
 
 #define QT_FEATURE_qtplugininfo 1
 
+
+#endif // QT_FEATURES_Tools_src_global_qttools_config_p_h_H
